@@ -1,9 +1,7 @@
 package Geo::Coordinates::Converter::Point;
-
 use strict;
 use warnings;
-
-use base qw( Class::Accessor::Fast );
+use parent 'Class::Accessor::Fast';
 __PACKAGE__->mk_accessors(qw/ lat lng datum format height /);
 
 use Storable ();
@@ -104,7 +102,7 @@ clone object
 
 =head1 AUTHOR
 
-Kazuhiro Osawa E<lt>ko@yappo.ne.jpE<gt>
+Kazuhiro Osawa E<lt>yappo {at} shibuya {dot} plE<gt>
 
 =head1 LICENSE
 
